@@ -14,12 +14,12 @@
 #    under the License.
 
 
+import array
 import binascii
 import os
 
 from os_brick.encryptors import base
 from os_brick import exception
-from os_brick.i18n import _LW
 from oslo_concurrency import processutils
 from oslo_log import log as logging
 
@@ -90,8 +90,8 @@ class CryptsetupEncryptor(base.VolumeEncryptor):
             # normal disk or multipath device), exit_code will be 1. In the
             # case, we will omit the warning message.
             if e.exit_code != 1:
-                LOG.warning(_LW('cryptsetup status %(dev_name) exited '
-                                'abnormally (status %(exit_code)s): %(err)s'),
+                LOG.warning('cryptsetup status %(dev_name)s exited '
+                            'abnormally (status %(exit_code)s): %(err)s',
                             {"dev_name": dev_name, "exit_code": e.exit_code,
                              "err": e.stderr})
             return False
@@ -127,6 +127,17 @@ class CryptsetupEncryptor(base.VolumeEncryptor):
                       check_exit_code=True, run_as_root=True,
                       root_helper=self._root_helper)
 
+    def _get_mangled_passphrase(self, key):
+        """Convert the raw key into a list of unsigned int's and then a string
+        """
+        # NOTE(lyarwood): This replicates the methods used prior to Newton to
+        # first encode the passphrase as a list of unsigned int's before
+        # decoding back into a string. This method strips any leading 0's
+        # of the resulting hex digit pairs, resulting in a different
+        # passphrase being returned.
+        encoded_key = array.array('B', key).tolist()
+        return ''.join(hex(x).replace('0x', '') for x in encoded_key)
+
     def attach_volume(self, context, **kwargs):
         """Shadows the device and passes an unencrypted version to the
         instance.
@@ -139,7 +150,16 @@ class CryptsetupEncryptor(base.VolumeEncryptor):
         key = self._get_key(context).get_encoded()
         passphrase = self._get_passphrase(key)
 
-        self._open_volume(passphrase, **kwargs)
+        try:
+            self._open_volume(passphrase, **kwargs)
+        except processutils.ProcessExecutionError as e:
+            if e.exit_code == 2:
+                # NOTE(lyarwood): Workaround bug#1633518 by attempting to use
+                # a mangled passphrase to open the device..
+                LOG.info("Unable to open %s with the current passphrase, "
+                         "attempting to use a mangled passphrase to open "
+                         "the volume.", self.dev_path)
+                self._open_volume(self._get_mangled_passphrase(key), **kwargs)
 
         # modify the original symbolic link to refer to the decrypted device
         self._execute('ln', '--symbolic', '--force',
