@@ -109,7 +109,7 @@ class HyperScaleConnector(base.BaseLinuxConnector):
             raise exception.BrickException(message=msg)
 
         device_info['vsa_ip'] = payload.get('vsa_ip')
-        device_info['device_path'] = (
+        device_info['path'] = (
             '/dev/' + connection_properties['name'][1:32])
         refl_factor = int(payload.get('refl_factor'))
         device_info['refl_factor'] = str(refl_factor)
